@@ -68,8 +68,6 @@ int main(int argc, char ** argv)
     KCrash::initialize();
 
     QCommandLineParser parser;
-    parser.addVersionOption();
-    parser.addHelpOption();
     aboutData.setupCommandLine(&parser);
     parser.process(a);
     aboutData.processCommandLine(&parser);
